@@ -9,7 +9,7 @@ use Cwd qw( cwd abs_path );
 
 use Git::Repository::Command;
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 # a few simple accessors
 for my $attr (qw( repo_path wc_path )) {
@@ -104,8 +104,11 @@ sub run {
     # something's wrong
     if (@errput) {
         my $errput = join "\n", @errput;
-        if   ( $command->{exit} == 128 ) { croak $errput; }
-        else                             { carp $errput; }
+        my $exit = $command->{exit};
+
+        # exit codes: 128 => fatal, 129 => usage
+        if   ( $exit == 128 || $exit == 129 ) { croak $errput; }
+        else                                  { carp $errput; }
     }
 
     # return the output
